@@ -558,7 +558,7 @@ class raw_env(AECEnv, EzPickle):
         Supports console print only.
         """
         if self.render_mode is None:
-            gymnasium.logger.WARN(
+            gymnasium.logger.warn(
                 "You are calling render method without specifying any render mode."
             )
             return
