@@ -58,7 +58,7 @@ simple_reference_v2.env(local_ratio=0.5, max_cycles=25, continuous_actions=False
 """
 
 import numpy as np
-from gym.utils import EzPickle
+from gymnasium.utils import EzPickle
 
 from pettingzoo.utils.conversions import parallel_wrapper_fn
 
@@ -68,19 +68,29 @@ from .._mpe_utils.simple_env import SimpleEnv, make_env
 
 
 class raw_env(SimpleEnv, EzPickle):
-    def __init__(self, local_ratio=0.5, max_cycles=25, continuous_actions=False):
+    def __init__(
+        self, local_ratio=0.5, max_cycles=25, continuous_actions=False, render_mode=None
+    ):
         EzPickle.__init__(
             self,
             local_ratio,
             max_cycles,
             continuous_actions,
+            render_mode,
         )
         assert (
             0.0 <= local_ratio <= 1.0
         ), "local_ratio is a proportion. Must be between 0 and 1."
         scenario = Scenario()
         world = scenario.make_world()
-        super().__init__(scenario, world, max_cycles, continuous_actions, local_ratio)
+        super().__init__(
+            scenario=scenario,
+            world=world,
+            render_mode=render_mode,
+            max_cycles=max_cycles,
+            continuous_actions=continuous_actions,
+            local_ratio=local_ratio,
+        )
         self.metadata["name"] = "simple_reference_v2"
 
 
