@@ -78,7 +78,7 @@ simple_world_comm.env(num_good=2, num_adversaries=4, num_obstacles=1,
 """
 
 import numpy as np
-from gym.utils import EzPickle
+from gymnasium.utils import EzPickle
 
 from pettingzoo.utils.conversions import parallel_wrapper_fn
 
@@ -97,6 +97,7 @@ class raw_env(SimpleEnv, EzPickle):
         max_cycles=25,
         num_forests=2,
         continuous_actions=False,
+        render_mode=None,
     ):
         EzPickle.__init__(
             self,
@@ -106,12 +107,19 @@ class raw_env(SimpleEnv, EzPickle):
             max_cycles,
             num_forests,
             continuous_actions,
+            render_mode,
         )
         scenario = Scenario()
         world = scenario.make_world(
             num_good, num_adversaries, num_obstacles, num_food, num_forests
         )
-        super().__init__(scenario, world, max_cycles, continuous_actions)
+        super().__init__(
+            scenario=scenario,
+            world=world,
+            render_mode=render_mode,
+            max_cycles=max_cycles,
+            continuous_actions=continuous_actions,
+        )
         self.metadata["name"] = "simple_world_comm_v2"
 
 
